.. _collections_contributions:

*************************************
Ansible Collections Contributor Guide
*************************************

.. toctree::
   :maxdepth: 2

   collection_development_process
   reporting_collections
   create_pr_quick_start
   collection_contributors/test_index
   collection_contributors/collection_reviewing
   maintainers
   contributing_maintained_collections
   steering/steering_index
   documentation_contributions
   other_tools_and_programs



If you have a specific Ansible interest or expertise (for example, VMware, Linode, and so on, consider joining a :ref:`working group <working_group_list>`.

Working with the Ansible collection repositories
=================================================

* How can I find :ref:`editors, linters, and other tools <other_tools_and_programs>` that will support my Ansible development efforts?
* Where can I find  guidance on :ref:`coding in Ansible <developer_guide>`?
* How do I :ref:`create a collection <developing_modules_in_groups>`?
* How do I :ref:`rebase my PR <rebase_guide>`?
* How do I learn about Ansible's :ref:`testing (CI) process <developing_testing>`?
* How do I :ref:`deprecate a module <deprecating_modules>`?
* See `Collection developer tutorials <https://www.ansible.com/products/ansible-community-training>`_ for a quick introduction on how to develop and test your collection contributions.
